Package: sofa
Title: Connector to 'CouchDB'
Description: Provides an interface to the 'NoSQL' database 'CouchDB'
    (<http://couchdb.apache.org>). Methods are provided for managing
    databases within 'CouchDB', including creating/deleting/updating/transferring,
    and managing documents within databases. One can connect with a local
    'CouchDB' instance, or a remote 'CouchDB' databases such as 'Cloudant'. 
    Documents can be inserted directly from vectors, lists, data.frames, 
    and 'JSON'. Targeted at 'CouchDB' v2 or greater.
Version: 0.4.0
Authors@R: c(
    person("Scott", "Chamberlain", role = c("aut", "cre"),
        email = "myrmecocystus@gmail.com", 
        comment = c(ORCID="0000-0003-1444-9135")),
    person(given = "rOpenSci",
        role = "fnd",
        comment = "https://ropensci.org/")
    )
License: MIT + file LICENSE
URL: https://github.com/ropensci/sofa (devel)
        https://docs.ropensci.org/sofa (docs)
BugReports: https://github.com/ropensci/sofa/issues
Encoding: UTF-8
VignetteBuilder: knitr
Imports: crul (>= 0.4.0), jsonlite (>= 1.5), R6 (>= 2.2.2), mime
Suggests: testthat, knitr, rmarkdown
RoxygenNote: 7.1.0
X-schema.org-applicationCategory: Databases
X-schema.org-keywords: CouchDB, database, NoSQL, documents
X-schema.org-isPartOf: https://ropensci.org
NeedsCompilation: no
Packaged: 2020-06-26 14:29:31 UTC; sckott
Author: Scott Chamberlain [aut, cre] (<https://orcid.org/0000-0003-1444-9135>),
  rOpenSci [fnd] (https://ropensci.org/)
Maintainer: Scott Chamberlain <myrmecocystus@gmail.com>
Repository: CRAN
Date/Publication: 2020-06-26 15:10:03 UTC
Built: R 4.6.0; ; 2026-04-27 12:53:29 UTC; unix
