# Generated by roxygen2: do not edit by hand

S3method(db_bulk_create_,character)
S3method(db_bulk_create_,data.frame)
S3method(db_bulk_create_,list)
S3method(db_bulk_update_,data.frame)
S3method(db_bulk_update_,default)
export(Cushion)
export(active_tasks)
export(attach_get)
export(db_alldocs)
export(db_bulk_create)
export(db_bulk_get)
export(db_bulk_update)
export(db_changes)
export(db_compact)
export(db_create)
export(db_delete)
export(db_explain)
export(db_index)
export(db_index_create)
export(db_index_delete)
export(db_info)
export(db_list)
export(db_query)
export(db_replicate)
export(db_revisions)
export(design_create)
export(design_create_)
export(design_delete)
export(design_get)
export(design_head)
export(design_info)
export(design_search)
export(design_search_many)
export(doc_attach_create)
export(doc_attach_delete)
export(doc_attach_get)
export(doc_attach_info)
export(doc_create)
export(doc_delete)
export(doc_get)
export(doc_head)
export(doc_update)
export(doc_upsert)
export(membership)
export(parse_df)
export(ping)
export(restart)
export(session)
export(uuids)
importFrom(R6,R6Class)
importFrom(crul,HttpClient)
importFrom(jsonlite,fromJSON)
importFrom(jsonlite,toJSON)
importFrom(jsonlite,unbox)
